netapp_ontap.models.nvme_subsystem_host_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nvme_subsystem_host_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NvmeSubsystemHostRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NvmeSubsystemHostRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `dh_hmac_chap: NvmeDhHmacChapAuthentication GET POST`

    A container for the configuration of NVMe in-band authentication using the DH-HMAC-CHAP protocol for a host.

  `io_queue: NvmeSubsystemHostRecordsIoQueue GET`

    The properties of the submission queue used to submit I/O commands for execution by the NVMe controller.

  `links: SelfLink GET`

    The links field of the nvme_subsystem_host_records.

  `nqn: str GET POST`

    The NVMe qualified name (NQN) used to identify the NVMe storage target. Not allowed in POST when the `records` property is used.

    Example: nqn.1992-01.example.com:string

  `subsystem: NvmeSubsystemHostRecordsSubsystem GET`

    The NVMe subsystem to which the NVMe host has been provisioned.

  `tls: NvmeTcpTls GET POST`

    A container for the configuration for NVMe/TCP-TLS transport session for the host.